@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Test::Routine;
 {
-  $Test::Routine::VERSION = '0.013';
+  $Test::Routine::VERSION = '0.015';
 }
 # ABSTRACT: composable units of assertion
 
@@ -105,7 +105,7 @@ Test::Routine - composable units of assertion
 
 =head1 VERSION
 
-version 0.013
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -144,7 +144,7 @@ B<The interface of Test::Routine is still open to some changes.>
     is( $self->fixture->things_done, 1, "we have done one thing already");
   };
 
-  test_me;
+  run_me;
   done_testing;
 
 =head1 DESCRIPTION
